Documentation see https://dpowers.readthedocs.io.

This package has not been tested properly, but is running well on my PC 
(Linux Mint). There are probably some bugs still. Help for testing and bug 
reporting is appreciated.

If you have question about a specific part or command of this project, let 
me know. I can focus my work depending on the features mostly needed.

Ideas for the future:
- Extend the documentation. (Reference for all commands, more examples, 
  tutorials.)
- Add support for multiple systems/platforms.
- More testing and debugging.
- Explanations on how to add your own powers or backends.